@@ -686,7 +686,6 @@ sprites3d   <- function(x, y = NULL, z = NULL, radius = 1,
   }
   savepar <- par3d(skipRedraw=TRUE, ignoreExtent=TRUE)
   on.exit(par3d(savepar), add=TRUE)
-  force(shapes)
   
   par3d(ignoreExtent=savepar$ignoreExtent)
   # Force evaluation of args
@@ -699,6 +698,26 @@ sprites3d   <- function(x, y = NULL, z = NULL, radius = 1,
   radius  <- rgl.attr(radius, ncenter)
   nradius <- length(radius)
   
+  if (is.list(shapes)) {
+    nshapelens <- length(shapes)
+    if (!nshapelens)
+      stop("Must have at least one shape")
+    
+    shapelens <- vapply(shapes, length, 1L)
+    shapes <- unlist(shapes)
+  } else if (length(shapes)) {
+    nshapelens <- 1
+    shapelens <- length(shapes)
+  } else {
+    nshapelens <- 0
+    shapelens <- NULL
+  }
+  
+  if (any(is.na(shapes)))
+    stop("shapes must not be NA")
+  
+  nshapes <- length(shapes)
+    
   pos <- as.integer(pos)
   npos <- length(pos)
   if (npos) {
@@ -709,8 +728,9 @@ sprites3d   <- function(x, y = NULL, z = NULL, radius = 1,
   if (ncenter && nradius) {
     if (length(shapes) && length(userMatrix) != 16) stop("Invalid 'userMatrix'")
     if (length(fixedSize) != 1) stop("Invalid 'fixedSize'")
-    idata   <- as.integer( c(ncenter,nradius,length(shapes), fixedSize, npos, rotating) )
-    
+
+    idata   <- as.integer( c(ncenter,nradius,nshapes, fixedSize, npos, rotating, 
+                             nshapelens, shapelens ) )
     ret <- .C( rgl_sprites,
                success = as.integer(FALSE),
                idata,
@@ -1079,8 +1099,9 @@ snapshot3d <- function(filename = tempfile(fileext = ".png"),
                          elementId = "webshot",
                          width = width,
                          height = height,
-                         webgl = TRUE), 
-               f1)
+                         webgl = TRUE),
+               f1,
+               selfcontained = FALSE)
     unlink(filename)
     res <- try(capture.output(webshot2::webshot(f1, file = filename, selector = "#webshot",
                         vwidth = width + 100, vheight = height, ...),
