@@ -34,16 +34,19 @@ rm(fns)
 
 rglwidgetOutput <- function(outputId, width = '512px', height = '512px') {
 	registerShinyHandlers()
-	shinyWidgetOutput(outputId, 'rglWebGL', width, height, package = 'rgl')
+	tagList(tags$p("3D plot", id = ariaLabelId(outputId), hidden = NA),
+	  shinyWidgetOutput(outputId, 'rglWebGL', width, height, package = 'rgl'))
 }
 
 # Widget render function for use in Shiny
 
 renderRglwidget <- function(expr, env = parent.frame(), quoted = FALSE, outputArgs = list()) {
+  
 	registerShinyHandlers()
+  
 	if (!quoted) expr <- substitute(expr)  # force quoted
-	shiny::markRenderFunction(rglwidgetOutput,
-														shinyRenderWidget(expr, rglwidgetOutput, env, quoted = TRUE),
+	
+	shiny::markRenderFunction(rglwidgetOutput,										shinyRenderWidget(expr, rglwidgetOutput, env, quoted = TRUE),
 														outputArgs = outputArgs)
 }
 
