@@ -40,7 +40,7 @@ decorate3d()
 bg3d("lightgray")
 aspect3d(1,1,1)
 
-## ---- eval = FALSE------------------------------------------------------------
+## ----eval = FALSE-------------------------------------------------------------
 #  myview <- par3d("userMatrix")
 #  # ... later ...
 #  par3d(userMatrix = myview)
@@ -49,7 +49,7 @@ aspect3d(1,1,1)
 filename <- tempfile(fileext = ".png")
 png(filename = filename)
 plot(rnorm(1000), rnorm(1000))
-dev.off()
+safe.dev.off()
 open3d()
 xyz <- cbind(c(0,1,1,0), 0, c(0,0,1,1))
 quads3d(xyz, texture = filename, texcoords = xyz[,c(1, 3)]*2, 
