@@ -250,13 +250,11 @@ void Background::getAttribute(SceneNode* subscene, AttribID attrib, int first, i
   }
 }
 
-String Background::getTextAttribute(SceneNode* subscene, AttribID attrib, int index)
+std::string Background::getTextAttribute(SceneNode* subscene, AttribID attrib, int index)
 {
   int n = getAttributeCount(subscene, attrib);
-  if (index < n && attrib == TYPES) {
-    char* buffer = R_alloc(20, 1);    
-    quad->getTypeName(buffer, 20);
-    return String(static_cast<int>(strlen(buffer)), buffer);
-  } else
+  if (index < n && attrib == TYPES)
+    return quad->getTypeName();
+  else
     return Shape::getTextAttribute(subscene, attrib, index);
 }
