@@ -37,16 +37,19 @@ public:
     delete [] fontname;
   }
   
-  virtual void draw(const char* text, int length, double adjx, double adjy, 
+  virtual void draw(const char* text, int length, 
+                    double adjx, double adjy, double adjz,
                     int pos, const RenderContext& rc) = 0;
-  virtual void draw(const wchar_t* text, int length, double adjx, double adjy, 
+  virtual void draw(const wchar_t* text, int length, 
+                    double adjx, double adjy, double adjz,
                     int pos, const RenderContext& rc) = 0;
   virtual double width(const char* text) = 0;
   virtual double width(const wchar_t* text) = 0;
   virtual double height() = 0;
   virtual bool valid(const char* text) { return true; };
   // justify returns false if justification puts the text outside the viewport
-  GLboolean justify(double width, double height, double adjx, double adjy,
+  GLboolean justify(double width, double height, 
+                    double adjx, double adjy, double adjz,
                     int pos, const RenderContext& rc);
   
   char* family;
@@ -85,9 +88,11 @@ public:
     GLFont(in_family, in_style, in_cex, in_fontname, false) {};
   ~GLBitmapFont();
 
-  void draw(const char* text, int length, double adjx, double adjy, 
+  void draw(const char* text, int length, 
+            double adjx, double adjy, double adjz,
             int draw, const RenderContext& rc);
-  void draw(const wchar_t* text, int length, double adjx, double adjy,
+  void draw(const wchar_t* text, int length, 
+            double adjx, double adjy, double adjz,
             int draw, const RenderContext& rc); 
   double width(const char* text);
   double width(const wchar_t* text);
@@ -113,9 +118,11 @@ public:
   
   ~GLFTFont();
 #ifdef HAVE_FREETYPE
-  void draw(const char* text, int length, double adjx, double adjy, 
+  void draw(const char* text, int length, 
+            double adjx, double adjy, double adjz,
             int pos, const RenderContext& rc);
-  void draw(const wchar_t* text, int length, double adjx, double adjy, 
+  void draw(const wchar_t* text, int length, 
+            double adjx, double adjy, double adjz,
             int pos, const RenderContext& rc);
   double width(const char* text);
   double width(const wchar_t* text);
@@ -137,9 +144,11 @@ public:
   NULLFont(const char* in_family, int in_style, double in_cex, bool useFreeType): 
     GLFont(in_family, in_style, in_cex, "NULL", useFreeType) {};
 
-  void draw(const char* text, int length, double adjx, double adjy, 
+  void draw(const char* text, int length, 
+            double adjx, double adjy, double adjz,
             int pos, const RenderContext& rc) {};
-  void draw(const wchar_t* text, int length, double adjx, double adjy, 
+  void draw(const wchar_t* text, int length, 
+            double adjx, double adjy, double adjz,
             int pos, const RenderContext& rc) {}; 
   double width(const char* text) {return 0.0;};
   double width(const wchar_t* text) {return 0.0;};
