@@ -3,12 +3,17 @@ suppressPackageStartupMessages(library(rgl))
 options(rgl.useNULL=TRUE)
 options(rgl.printRglwidget=FALSE)
 
-if (!requireNamespace("rmarkdown", quietly = TRUE) || 
-    !rmarkdown::pandoc_available("1.14")) {
-  warning(call. = FALSE, "These vignettes assume rmarkdown and pandoc version 1.14.  These were not found. Older versions will not work.")
+if (!requireNamespace("rmarkdown", quietly = TRUE)) {
+  warning(call. = FALSE, "These vignettes assume rmarkdown is installed.  It was not found.")
   knitr::knit_exit()
 }
 
+# If Pandoc is not installed, the output format won't be set
+# knitr needs this; see https://github.com/rstudio/markdown/issues/115
+if (is.null(knitr::opts_knit$get("rmarkdown.output.format"))){
+  knitr::opts_knit$set(rmarkdown.pandoc.to = "html")
+}
+  
 # knitr::opts_chunk$set(snapshot = TRUE)  # for snapshots instead of dynamic
 
 documentedfns <- c()
